from invoke import task


@task(help={"filename": "The filename to encrypt."})
def encrypt(c, filename):
    """
    Generate an encrypted version of the file using OpenSSL.
    """
    c.run(
        f'openssl aes-256-cbc -md sha256 -k "$DECRYPT_PASSWORD" -in {filename} -out {filename}.enc'
    )


@task(help={"filename": "The filename (not including .enc) to decrypt."})
def decrypt(c, filename):
    """
    Generate an decrypted version of the file using OpenSSL.
    """
    c.run(
        f'openssl aes-256-cbc -md sha256 -k "$DECRYPT_PASSWORD" -in {filename}.enc -out {filename} -d'
    )



import os

from invoke import Exit, task


def _get_package_version(c):
    return c.run('poetry version --no-ansi | cut -d" " -f2').stdout.strip()


def _get_pyproject_filename(c):
    git_root = c.run("git rev-parse --show-toplevel").stdout.strip()
    return os.path.join(git_root, "pyproject.toml")


def _is_git_dirty(c):
    dirty_files = c.run("git status --porcelain").stdout.strip()
    return bool(dirty_files)


@task(
    help={
        "rule": "A valid semver string or a valid bump rule (eg. patch, minor, major, etc.)"
    }
)
def bump(c, rule):
    """
    Bumps the version of the package in pyproject.toml. Then commits, tags, and pushes the new version.
    """
    if _is_git_dirty(c):
        raise Exit("This repo has uncommitted changes. Aborting...")

    previous_version = _get_package_version(c)
    c.run(f"poetry version {rule}")
    pyproject_filename = _get_pyproject_filename(c)
    c.run(f"git add {pyproject_filename}")
    updated_version = _get_package_version(c)
    c.run(
        f"git commit -m 'chore: bump version from {previous_version} to {updated_version}'"
    )
    c.run(f"git tag -a '{updated_version}' -m 'version {updated_version}'")
    c.run("git push --follow-tags")



import os
import sys

from invoke import task


def _get_pyupgrade_python_version_arg():
    python_version = sys.version_info
    for minor_version in (8, 7):
        if python_version >= (3, minor_version):
            return f"--py3{minor_version}-plus"
    else:
        return "--py36-plus"


def _is_django_installed():
    try:
        import django
    except ImportError:
        return False
    else:
        return True


def _is_django_project():
    return _is_django_installed() and os.path.exists("./manage.py")


@task
def pyupgrade(c):
    """
    Upgrade Python syntax using pyupgrade.
    Exits non-zero if any changes are made, so doubles as a check.
    """
    python_version_arg = _get_pyupgrade_python_version_arg()
    c.run(f"pyupgrade {python_version_arg} $(find . -name '*.py')")


@task
def isort(c):
    """
    Check Python code for incorrectly-sorted imports.
    """
    c.run("isort . --check")


@task
def black(c):
    """
    Check Python code for style errors.
    """
    c.run("black . --check")


@task
def migrations(c):
    """
    Check Django models for outstanding changes.
    """
    c.run("./manage.py makemigrations --check")


@task(default=True)
def all(c):
    """
    Perform all checks.
    """
    pyupgrade(c)
    isort(c)
    black(c)

    # It only makes sense to perform migration checks on Django projects
    if _is_django_project():
        migrations(c)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['opstrich', 'opstrich.invoke']

package_data = \
{'': ['*']}

install_requires = \
['black==22.1.0', 'invoke>=1.4.1,<2.0.0', 'isort==5.10.1', 'pyupgrade==2.31.0']

setup_kwargs = {
    'name': 'opstrich',
    'version': '0.7.0',
    'description': 'DevOps tooling, various scripts, etc.',
    'long_description': '# Opstrich\n#### DevOps tooling, various scripts, etc.\n\n![CI](https://github.com/RevolutionTech/opstrich/actions/workflows/ci.yml/badge.svg)\n\n## Installation\n\nFirst install the `opstrich` package:\n\n    pip install opstrich\n\nTo use the provided [invoke](http://www.pyinvoke.org/) tasks, you will also need to add these to a collection in your project:\n\n    # tasks.py\n\n    from invoke import Collection\n    from opstrich.invoke import check, openssl, package\n\n    namespace = Collection(check, openssl, package)\n\n## Usage\n\nOnce the invoke tasks have been added, you can view help information on them via `inv -l` and `inv --help`.\n',
    'author': 'Lucas Connors',
    'author_email': 'lucas@revolutiontech.ca',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/RevolutionTech/opstrich',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.2,<4.0.0',
}


setup(**setup_kwargs)
